@@ -1,5 +1,5 @@
 class Platform():
-	registry = dict()
+	registry = {}
 
 	def __init__(self, id, name, is_brand_missing_from_name, platform_family_id, platform_family_name, model_no, storage_capacity, description, disambiguation, relevance):
 		self.id = id
